..
    Copyright (C) 2023 Graz University of Technology.

    invenio-records-global-search is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

Changes
=======

Version v0.2.1 (release 2023-11-23)

- translations: update
- facets: implement better wording for datamodel


Version v0.2.0 (release 2023-11-09)




Version v0.1.0 (release 2023-11-09)



